pub struct VdividerIoView<SubstrateV>where
InOut<Signal>: HasView<SubstrateV>,
Output<Signal>: HasView<SubstrateV>,{
pub vdd: <InOut<Signal> as HasView<SubstrateV>>::View,
pub vss: <InOut<Signal> as HasView<SubstrateV>>::View,
pub dout: <Output<Signal> as HasView<SubstrateV>>::View,
}Fields
vdd: <InOut<Signal> as HasView<SubstrateV>>::Viewvss: <InOut<Signal> as HasView<SubstrateV>>::Viewdout: <Output<Signal> as HasView<SubstrateV>>::ViewImplementations
Sourceimpl VdividerIoView<NodeBundle>where
InOut<Signal>: HasSchematicBundleKindViews,
Output<Signal>: HasSchematicBundleKindViews,
Self: HasBundleKind<BundleKind: SchematicBundleKind<NodeBundle = Self>>,
impl VdividerIoView<NodeBundle>where
InOut<Signal>: HasSchematicBundleKindViews,
Output<Signal>: HasSchematicBundleKindViews,
Self: HasBundleKind<BundleKind: SchematicBundleKind<NodeBundle = Self>>,
Sourceimpl VdividerIoView<TerminalBundle>where
InOut<Signal>: HasSchematicBundleKindViews,
Output<Signal>: HasSchematicBundleKindViews,
Self: HasBundleKind<BundleKind: SchematicBundleKind<TerminalBundle = Self>>,
impl VdividerIoView<TerminalBundle>where
InOut<Signal>: HasSchematicBundleKindViews,
Output<Signal>: HasSchematicBundleKindViews,
Self: HasBundleKind<BundleKind: SchematicBundleKind<TerminalBundle = Self>>,
Sourcepub fn view_as<SubstrateT: HasBundleKind<BundleKind: SchematicBundleKind>>(
&self,
) -> TerminalBundle<<SubstrateT as HasBundleKind>::BundleKind>where
<Self as HasBundleKind>::BundleKind: DataView<<SubstrateT as HasBundleKind>::BundleKind>,
pub fn view_as<SubstrateT: HasBundleKind<BundleKind: SchematicBundleKind>>(
&self,
) -> TerminalBundle<<SubstrateT as HasBundleKind>::BundleKind>where
<Self as HasBundleKind>::BundleKind: DataView<<SubstrateT as HasBundleKind>::BundleKind>,
Views this bundle as a bundle of a different kind.
Sourcepub fn node_bundle(&self) -> NodeBundle<<Self as HasBundleKind>::BundleKind>
pub fn node_bundle(&self) -> NodeBundle<<Self as HasBundleKind>::BundleKind>
Views this terminal bundle as a node bundle of the same kind.